pub enum Error {
NotInitialized(String),
AlreadyInitialized(String),
TicketNotFound(String),
ListNotFound(String),
ThreadNotFound(String),
PostNotFound(String),
Message(String),
Io(Error),
Json(Error),
}Expand description
All errors that wipe-core can produce.
Variants
NotInitialized(String)
No .wipe board was found at the given path or any of its ancestors.
AlreadyInitialized(String)
A .wipe board already exists where one was about to be created.
TicketNotFound(String)
A ticket with the given ID does not exist.
ListNotFound(String)
A list with the given ID does not exist.
ThreadNotFound(String)
A forum thread with the given ID does not exist.
PostNotFound(String)
A forum post with the given ID does not exist.
Message(String)
A generic, contextual error message.
Io(Error)
An underlying filesystem error.
Json(Error)
A JSON (de)serialization error.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn msg(m: impl Into<String>) -> Self
pub fn msg(m: impl Into<String>) -> Self
Build a Error::Message from anything string-like.
Sourcepub fn not_initialized(p: impl AsRef<Path>) -> Self
pub fn not_initialized(p: impl AsRef<Path>) -> Self
Build a Error::NotInitialized from a path.