remove_list

Function remove_list 

pub fn remove_list(
    store: &Store,
    list_id: &str,
    force: bool,
    now: DateTime<Utc>,
) -> Result<()>
Remove a list. Fails if the list still holds cards, unless force is set (in which case the contained tickets are also deleted).