pub fn file_at_commit( root: &Path, rev: &str, relpath: &str, ) -> Result<Option<String>>
Read the contents of a tracked file as of a specific commit/ref. Returns None if the file did not exist at that revision.
None